#
# spec file for package qactus
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2018 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global libmajor 2
%global libprefix libqobs
%global libname %{libprefix}%{libmajor}
%global devname %{libprefix}-devel

Name:           qactus
Version:        2.1.0
Release:        2.17
Summary:        A GUI client for OBS
License:        GPL-2.0-only OR GPL-3.0-only
Group:          Development/Tools/Building
URL:            https://github.com/javierllorente/qactus
Source:         %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM qactus-fix-leap-build.patch
Patch0:         qactus-fix-leap-build.patch
BuildRequires:  cmake >= 3.5
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Widgets)
# Needed to ensure Qt5Keychain can be used properly
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Keychain)
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description
A Qt-based Open Build Service (OBS) client featuring a browser, request
management and more.

%package -n %{libname}
Summary:        A Qt-based OBS library
Group:          System/Libraries

%description -n %{libname}
A library for interacting with the Open Build Service (OBS).

%package -n %{devname}
Summary:        Development files for %{libprefix}
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{devname}
This package contains the development files for %{libprefix}, a Qt-based
Open Build Service (OBS) library.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%suse_update_desktop_file %{name}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%doc README.md
%license COPYING gpl-*.txt
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/128x128/apps/%{name}.png

%files -n %{libname}
%license COPYING gpl-*.txt
%{_libdir}/%{libprefix}.so.%{libmajor}
%{_libdir}/%{libprefix}.so.%{libmajor}.*

%files -n %{devname}
%{_libdir}/%{libprefix}.so
%{_libdir}/pkgconfig/%{libprefix}.pc
%{_includedir}/qobs

%changelog
* Tue Oct  5 2021 Javier Llorente <javier@opensuse.org>
- Fix build for openSUSE Leap 15.2 and 15.3
  * qactus-fix-leap-build.patch
* Fri Sep 17 2021 Javier Llorente <javier@opensuse.org>
- Update to 2.1.0
  * New feature: monitor an entire project
* Sat Nov 28 2020 Javier Llorente <javier@opensuse.org>
- Update to 2.0.3
  * Minor fixes:
  - follow redirects
  - empty bookmark list on user switch
  * Improve the configure dialog
* Tue Jun 16 2020 Javier Llorente <javier@opensuse.org>
- Update to 2.0.2
  * RequestStateEditor enhancements:
  - enable keyboard navigation
  - add shortcuts for push buttons
* Mon May  4 2020 Javier Llorente <javier@opensuse.org>
- Update to 2.0.1
  * RequestStateEditor bugfixes:
  - get the full diff for the selected request
  - use the right OBS signal finishedParsingRequestStatus()
* Mon Apr 20 2020 Javier Llorente <javier@opensuse.org>
- Update to 2.0.0
  * Improved UI: revamped toolbar, new action toolbars, new side bar
  icons
  * New features such as bookmarks, meta config editor (beta), search
  widget for BuildLogViewer, showing outgoing and declined requests
  * Miscellaneous bugfixes and "hidden features" ;-)
* Sat Dec  1 2018 Javier Llorente <javier@opensuse.org>
- Update 1.0.1
  * Switch from QMake to CMake, rpm spec rewritten (Thanks Neal
  Gompa!)
  * Minor bugfixes
* Sun Nov 25 2018 Javier Llorente <javier@opensuse.org>
- libqobs.so is not packaged (for now)
* Sun Nov 25 2018 Javier Llorente <javier@opensuse.org>
- Update to 1.0.0
  * New: OBS browser
  * New: build log viewer
  * Improved request state editor
  * Split GUI code; libqobs is born
  * Bugs fixed, several small enhacements
* Fri Jul  1 2016 toddrme2178@gmail.com
- Change Group tag.
* Sun Aug 16 2015 javier@opensuse.org
-  Update to 0.7.0
  * New feature: you can now add packages by dropping OBS package URLs
  on the packages' tab
  * New feature: proxy support
  * New feature: self-signed certificate support
  * New feature: using any OBS instance is now supported
  * Networking improvements: async getBuildStatus() requests
  * Code refactoring: OBS façade created, some code cleanup
  * Error handling: it's more verbose about HTTP and SSL errors
  * Fixed getting description from OBSRequest
  * Fixed parsing empty tags (ie: <description/>)
  * Minor improvements
* Mon Jun 15 2015 javier@opensuse.org
- Update to 0.6.0
  * Qactus has been ported to Qt5
  * Fix getting timer interval from settings on startup
  * Request state editor improvements (displays more info)
  * Open request state editor on double click
  * Show tooltip on cell if text is truncated
  * Minor improvements
* Thu Apr 30 2015 javier@opensuse.org
- Update to 0.5.1
  * New feature: request diff is retrieved and displayed on
  request state change dialog
  * Row and request state change dialogs improved
  * Minor improvements
* Wed Apr 29 2015 javier@opensuse.org
- Update to 0.5.0
  * New feature: accepting/declining requests
  (right click->Change State)
* Fri Apr 17 2015 javier@opensuse.org
- Update to 0.4.3
  * Fix tray icon not set to red on change
  * New feature: shortcuts for add, remove, refresh and
  mark all as read
  * New feature: mark as read for a single build item
  * Minor improvements
* Thu Apr  9 2015 javier@opensuse.org
- Update to 0.4.2
  * New feature: 'Mark all as read'
* Sat Mar 14 2015 javier@opensuse.org
- Update to 0.4.1
  * New feature: auto login
- qactus-pro-file-cleanup.patch removed (merged upstream)
* Sun Mar  1 2015 malcolmlewis@opensuse.org
- Spec file clean up.
- Add qactus-pro-file-cleanup.patch: Clean up project file for
  install.
* Thu Feb 19 2015 javier@opensuse.org
- Initial package.
